<?php

defined('_JEXEC') or die('Restricted access');

class CrossfitModelSubscriptions extends JModelList {

    var $insertedId = null;

    public function __construct($config = array()) {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'idSubscription',
                'nome',
                'prezzo',
                'mesi',
                'descrizione',
                'published',
                'ad_ingressi',
                'ingressi',
                'giorniValidi'
            );
        }

        parent::__construct($config);
    }

    protected function getListQuery() {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);

        $query->select('*')->from($db->quoteName('#__crossfit_subscriptions'));

        $search = $this->getState('filter.search');

        if (!empty($search)) {
            $like = $db->quote('%' . $search . '%');
            $query->where('CONCAT(nome, " ", prezzo, " ", descrizione) LIKE ' . $like);
        }

        $published = $this->getState('filter.published');

        if (is_numeric($published)) {
            $query->where('published = ' . (int) $published);
        } elseif ($published === '') {
            $query->where('(published IN (0, 1))');
        }

        if (JRequest::getVar('id')) {
            $query->where('idSubscription = ' . (int) JRequest::getVar('id'));
        }

        $orderCol = $this->state->get('list.ordering');
        $orderDirn = $this->state->get('list.direction');
        if ($orderCol && $orderDirn) {
            $query->order($db->escape($orderCol) . ' ' . $db->escape($orderDirn));
        } else {
            $query->order("ad_ingressi DESC, ingressi, mesi, adIngressiTotali, ingressiTotali, mesi, nome");
        }

        return $query;
    }

    public function getItem() {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);

        $query->select('*')->from($db->quoteName('#__crossfit_subscriptions'))->where('idSubscription = ' . (int) JRequest::getVar('id'));

        $db->setQuery($query);

        return $db->loadObjectList();
    }

    public function getForm($data = array(), $loadData = true) {
        $form = $this->loadForm(
                'com_crossfit.subscriptions', 'subscription', array(
            'control' => 'jform',
            'load_data' => $loadData
                )
        );

        if (empty($form)) {
            return false;
        }

        return $form;
    }

    public function publish($published = 1) {
        $cid = JRequest::getVar('cid');
        $mainframe = JFactory::getApplication();
        $db = JFactory::getDbo();

        foreach ($cid as $id) {
            $data = new stdClass;
            $data->idSubscription = $id;
            $data->published = $published;
            $data->modified = date('Y-m-d H:i:s');
            $db->updateObject('#__crossfit_subscriptions', $data, 'idSubscription');
        }

        $mainframe->redirect('index.php?option=com_crossfit&view=subscriptions');
    }

    public function unpublish() {
        $this->publish(0);
    }

    public function delete($id = null) {
        if (!$id)
            return;

        $db = JFactory::getDbo();
        $query = $db->getQuery(true);

        $query->delete('#__crossfit_subscriptions')->where('idSubscription = ' . $query->quote($id));

        $db->setQuery($query);

        return $db->execute();
    }

    public function save() {
        $db = JFactory::getDbo();
        $post = JRequest::get('post');
        $post = $post['jform'];

        $data = new stdClass;
        $data->nome = $post['nome'];
        $data->prezzo = $post['prezzo'];
        $data->descrizione = $post['descrizione'];
        $data->mesi = $post['mesi'];
        $data->ingressiGiornalieri = $post['ingressiGiornalieri'];
        $data->ad_ingressi = $post['ad_ingressi'];
        $data->ingressi = $post['ingressi'];
        $data->adIngressiTotali = $post['adIngressiTotali'];
        $data->ingressiTotali = $post['ingressiTotali'];

        if (!$data->adIngressiTotali) {
            $data->ingressiTotali = null;
        }
        if (!$data->ad_ingressi) {
            $data->ingressi = null;
        }

        if ($post['idSubscription']) {
            $data->idSubscription = $post['idSubscription'];
            $data->modified = date('Y-m-d H:i:s');
            return $db->updateObject('#__crossfit_subscriptions', $data, idSubscription, true);
        } else {
            $data->created = date('Y-m-d H:i:s');
            $return = $db->insertObject('#__crossfit_subscriptions', $data, idSubscription, true);
            $this->insertedId = $db->insertid();
            return $return;
        }
    }

}
